@@ -1001,6 +1001,9 @@ class LinuxDistribution(object):
                              'fedora-release',
                              'gentoo-release',
                              'mageia-release',
+                             'mandrake-release',
+                             'mandriva-release',
+                             'mandrivalinux-release',
                              'manjaro-release',
                              'oracle-release',
                              'redhat-release',
